@@ -348,25 +348,23 @@ echo "bar" >2
         output = mm.dryrun()
 
         expected_output = """Step: basic test
-----
-would run 'bash -c' with command: `echo "test"`
-would run 'bash -c' with command: `echo "test2"`
----- Expected stdout ----
-test
-test2
----- end stdout ----
----- Expected stderr ----
----- end stderr ----
+\tcommands to run with 'bash -c':
+\t\t`echo "test"`
+\t\t`echo "test2"`
+\tExpected stdout:
+\t\ttest
+\t\ttest2
+\tExpected stderr:
+
 Step: step 2
-----
-would run 'bash -c' with command: `echo "foo"`
-would run 'bash -c' with command: `echo "bar" >2`
----- Expected stdout ----
-foo
----- end stdout ----
----- Expected stderr ----
-bar
----- end stderr ----
+\tcommands to run with 'bash -c':
+\t\t`echo "foo"`
+\t\t`echo "bar" >2`
+\tExpected stdout:
+\t\tfoo
+\tExpected stderr:
+\t\tbar
+
 """
         self.assertEqual(expected_output, output)
         self.popen_mock.assert_not_called()
